@@ -1,3 +1,5 @@
+from kilvin import log
+
 CONFIG_TEMP = """title = ''
 url = ''
 description = ''
@@ -7,13 +9,6 @@ name = ''
 email = ''
 """
 
-ARCHE_TEMP = """---
-title: ""
-date: ""
-draft: true
----
-"""
-
 CONFIG_FILE = "config.toml"
 
 
@@ -22,8 +17,8 @@ def gen_file(file_path, data):
         f.write(data)
 
 
-def init(path):
-    dirs = ["archetypes", "public", "content", "static", "layouts"]
+def create_project(path):
+    dirs = ["public", "content", "static", "layouts"]
 
     abs_path = path.absolute()
 
@@ -34,8 +29,7 @@ def init(path):
             dir_path.mkdir()
 
         gen_file(abs_path / CONFIG_FILE, CONFIG_TEMP)
-        gen_file(abs_path / "archetypes" / "default.md", ARCHE_TEMP)
 
-        print(f"{path} directory for the project created.")
+        log.succ(f"{path} directory for the project created.")
     except FileExistsError:
-        print("Directory already exists.")
+        log.info("Directory already exists.")
