@@ -1,5 +1,6 @@
 import sys
-from typing import Union
+
+from kilvin import log
 
 try:
     import tomllib
@@ -7,9 +8,8 @@ except ModuleNotFoundError:
     import tomli as tomllib
 
 
-def check_config(config) -> None:
-
-    def keys_exist(keys) -> bool:
+def check_config(config):
+    def keys_exist(keys):
         """Check for nested keys in config."""
 
         _elem = config
@@ -22,7 +22,6 @@ def check_config(config) -> None:
 
     keys = ["title", "url", "description", ["author", "name"], ["author", "email"]]
     is_incomplete = False
-
     for key in keys:
         if not isinstance(key, list):
             key = [key]
@@ -30,13 +29,13 @@ def check_config(config) -> None:
         if not keys_exist(key):
             is_incomplete = True
             key_str = ".".join(key)
-            print(f'"{key_str}" not found in config.toml.')
+            log.error(f'"{key_str}" not found in config.toml.')
 
     if is_incomplete:
         sys.exit(1)
 
 
-def load_config() -> dict[str, Union[str, int]]:
+def load_config():
     try:
         with open("config.toml", "rb") as cf:
             pass
@@ -45,8 +44,8 @@ def load_config() -> dict[str, Union[str, int]]:
                 check_config(config)
                 return config
             except tomllib.TOMLDecodeError:
-                print("Something is wrong with the config file.")
+                log.error("Something is wrong with the config file.")
                 sys.exit(1)
     except FileNotFoundError as e:
-        print(f"{e.filename} : {e.strerror}. Please add it.")
+        log.error(f"{e.filename} : {e.strerror}. Please add it.")
         sys.exit(1)
