@@ -4,6 +4,8 @@ import shutil
 import sys
 from pathlib import Path
 
+from kilvin import log
+
 DIR_PUBLIC = "public"
 
 
@@ -13,7 +15,7 @@ def is_kilvin_dir(func):
         cwd = pathlib.Path(".")
         config_path = cwd / "config.toml"
         if not config_path.exists():
-            print("Error: Unable to locate config file.")
+            log.error("Unable to locate config file.")
             sys.exit(1)
         return func(*args, **kwargs)
 
@@ -25,7 +27,7 @@ def clean_public():
     path = pathlib.Path(DIR_PUBLIC)
 
     if not path.exists():
-        print(f"{DIR_PUBLIC} does not exist")
+        log.error(f"{DIR_PUBLIC} does not exist")
         sys.exit(1)
 
     for fd in path.iterdir():
